@@ -1,6 +1,6 @@
 package Log::Any::Adapter::File;
 BEGIN {
-  $Log::Any::Adapter::File::VERSION = '0.08';
+  $Log::Any::Adapter::File::VERSION = '0.09';
 }
 use strict;
 use warnings;
@@ -35,11 +35,11 @@ __PACKAGE__->make_logging_methods(
 
 =head1 NAME
 
-Log::Any::Adapter::File
+Log::Any::Adapter::File - Simple adapter for logging to files
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
